import { PdfPaperSize } from "./paper";
/**
 * An option for {@link PdfDocument.fromImage}
 */
export interface ImageToPdfOptions {
    /**
     * Describes how image should be placed on the PDF page
     */
    imageBehavior: ImageBehavior;
    /**
     * Set an output paper size for PDF pages. Use {@link CustomPaperSize} for custom sizes.
     *
     * Default value is A4.
     */
    paperSize: PdfPaperSize;
}
/**
 * Supported image file type
 */
export declare enum ImageType {
    PNG = 0,
    JPG = 1,
    BMP = 2
}
/**
 * Describes how image should be placed on the PDF page
 */
export declare enum ImageBehavior {
    /**
     * Image should be placed on center of the page.
     */
    CenteredOnPage = 0,
    /**
     * Image should fit to the page.
     */
    FitToPage = 1,
    /**
     * Image should fit to the page and keep aspect ratio.
     */
    FitToPageAndMaintainAspectRatio = 2,
    /**
     * Page should fit to the image.
     */
    CropPage = 3,
    /**
     * Image should be placed to the left top corner of the page.
     */
    TopLeftCornerOfPage = 4,
    /**
     * Image should be placed to the left bottom corner of the page.
     */
    BottomLeftCornerOfPage = 5,
    /**
     * Image should be placed to the right top corner of the page.
     */
    TopRightCornerOfPage = 6,
    /**
     * Image should be placed to the right bottom corner of the page.
     */
    BottomRightCornerOfPage = 7
}
//# sourceMappingURL=image.d.ts.map