export declare type PdfPaperSize = PaperSize | CustomPaperSize;
/**
 * Defines the target virtual paper size the PDF.  Relates to real-world paper-sizes.
 */
export declare enum PaperSize {
    /**
     * 8.5in x 11in
     */
    Letter = 0,
    /**
     * 8.5in x 11in
     */
    Legal = 1,
    /**
     * 210mm x 297mm
     */
    A4 = 2,
    /**
     * 17in x 22in
     */
    CSheet = 3,
    /**
     * 22in x 34in
     */
    DSheet = 4,
    /**
     * 34in x 44in
     */
    ESheet = 5,
    /**
     * 8.5in x 11in
     */
    LetterSmall = 6,
    /**
     * 11in x 17in
     */
    Tabloid = 7,
    /**
     * 17in x 11in
     */
    Ledger = 8,
    /**
     * 5.5in x 8.5in
     */
    Statement = 9,
    /**
     * 7.25in x 10.5in
     */
    Executive = 10,
    /**
     * 297mm x 420mm
     */
    A3 = 11,
    /**
     * 210mm x 297mm
     */
    A4Small = 12,
    /**
     * 148mm x 210mm
     */
    A5 = 13,
    /**
     * 250mm x 353mm
     */
    B4 = 14,
    /**
     * 176mm x 250mm
     */
    B5 = 15,
    /**
     * 8.5in x 13in
     */
    Folio = 16,
    /**
     * 215mm x 275mm
     */
    Quarto = 17,
    /**
     * 10in x 14in
     */
    Standard10x14 = 18,
    /**
     * 11in x 17in
     */
    Standard11x17 = 19,
    /**
     * 8.5in x 11in
     */
    Note = 20,
    /**
     * 3.875in x 8.875in
     */
    Number9Envelope = 21,
    /**
     * 4.125in x 9.5in
     */
    Number10Envelope = 22,
    /**
     * 4.5in x 10.375in
     */
    Number11Envelope = 23,
    /**
     * 4.75in x 11in
     */
    Number12Envelope = 24,
    /**
     * 5in x 11.5in
     */
    Number14Envelope = 25,
    /**
     * 110mm x 220mm
     */
    DLEnvelope = 26,
    /**
     * 162mm x 229mm
     */
    C5Envelope = 27,
    /**
     * 324mm x 458mm
     */
    C3Envelope = 28,
    /**
     * 229mm x 324mm
     */
    C4Envelope = 29,
    /**
     * 114mm x 162mm
     */
    C6Envelope = 30,
    /**
     * 114mm x 229mm
     */
    C65Envelope = 31,
    /**
     * 250mm x 353mm
     */
    B4Envelope = 32,
    /**
     * 176mm x 250mm
     */
    B5Envelope = 33,
    /**
     * 176mm x 125mm
     */
    B6Envelope = 34,
    /**
     * 110mm x 230mm
     */
    ItalyEnvelope = 35,
    /**
     * 3.875in x 7.5in
     */
    MonarchEnvelope = 36,
    /**
     * 3.625in x 6.5in
     */
    PersonalEnvelope = 37,
    /**
     * 14.875in x 11in
     */
    USStandardFanfold = 38,
    /**
     * 8.5in x 12in
     */
    GermanStandardFanfold = 39,
    /**
     * 8.5in x 13in
     */
    GermanLegalFanfold = 40,
    /**
     * 250mm x 353mm
     */
    IsoB4 = 41,
    /**
     * 100mm x 148mm
     */
    JapanesePostcard = 42,
    /**
     * 9in x 11in
     */
    Standard9x11 = 43,
    /**
     * 10in x 11in
     */
    Standard10x11 = 44,
    /**
     * 15in x 11in
     */
    Standard15x11 = 45,
    /**
     * 220mm x 220mm
     */
    InviteEnvelope = 46,
    /**
     * 9.275in x 12in
     */
    LetterExtra = 47,
    /**
     * 9.275in x 15in
     */
    LegalExtra = 48,
    /**
     * 11.69in x 18in
     */
    TabloidExtra = 49,
    /**
     * 236mm x 322mm
     */
    A4Extra = 50,
    /**
     * 8.275in x 11in
     */
    LetterTransverse = 51,
    /**
     * 210mm x 297mm
     */
    A4Transverse = 52,
    /**
     * 9.275in x 12in
     */
    LetterExtraTransverse = 53,
    /**
     * 227mm x 356mm
     */
    APlus = 54,
    /**
     * 305mm x 487mm
     */
    BPlus = 55,
    /**
     * 8.5in x 12.69in
     */
    LetterPlus = 56,
    /**
     * 210mm x 330mm
     */
    A4Plus = 57,
    /**
     * 148mm x 210mm
     */
    A5Transverse = 58,
    /**
     * 182mm x 257mm
     */
    B5Transverse = 59,
    /**
     * 322mm x 445mm
     */
    A3Extra = 60,
    /**
     * 174mm x 235mm
     */
    A5Extra = 61,
    /**
     * 201mm x 276mm
     */
    B5Extra = 62,
    /**
     * 420mm x 594mm
     */
    A2 = 63,
    /**
     * 297mm x 420mm
     */
    A3Transverse = 64,
    /**
     * 322mm x 445mm
     */
    A3ExtraTransverse = 65,
    /**
     * 200mm x 148mm
     */
    JapaneseDoublePostcard = 66,
    /**
     * 105mm x 148mm
     */
    A6 = 67,
    /**
     * 11in x 8.5in
     */
    LetterRotated = 68,
    /**
     * 420mm x 297mm
     */
    A3Rotated = 69,
    /**
     * 297mm x 210mm
     */
    A4Rotated = 70,
    /**
     * 210mm x 148mm
     */
    A5Rotated = 71,
    /**
     * 364mm x 257mm
     */
    B4JisRotated = 72,
    /**
     * 257mm x 182mm
     */
    B5JisRotated = 73,
    /**
     * 148mm x 100mm
     */
    JapanesePostcardRotated = 74,
    /**
     * 148mm x 200mm
     */
    JapaneseDoublePostcardRotated = 75,
    /**
     * 148mm x 105mm
     */
    A6Rotated = 76,
    /**
     * 128mm x 182mm
     */
    B6Jis = 77,
    /**
     * 182mm x 128mm
     */
    B6JisRotated = 78,
    /**
     * 12in x 11in
     */
    Standard12x11 = 79,
    /**
     * 146mm x 215mm
     */
    Prc16K = 80,
    /**
     * 97mm x 151mm
     */
    Prc32K = 81,
    /**
     * 97mm x 151mm
     */
    Prc32KBig = 82,
    /**
     * 102mm x 165mm
     */
    PrcEnvelopeNumber1 = 83,
    /**
     * 102mm x 176mm
     */
    PrcEnvelopeNumber2 = 84,
    /**
     * 125mm x 176mm
     */
    PrcEnvelopeNumber3 = 85,
    /**
     * 110mm x 208mm
     */
    PrcEnvelopeNumber4 = 86,
    /**
     * 110mm x 220mm
     */
    PrcEnvelopeNumber5 = 87,
    /**
     * 120mm x 230mm
     */
    PrcEnvelopeNumber6 = 88,
    /**
     * 160mm x 230mm
     */
    PrcEnvelopeNumber7 = 89,
    /**
     * 120mm x 309mm
     */
    PrcEnvelopeNumber8 = 90,
    /**
     * 229mm x 324mm
     */
    PrcEnvelopeNumber9 = 91,
    /**
     * 324mm x 458mm
     */
    PrcEnvelopeNumber10 = 92,
    /**
     * 146mm x 215mm
     */
    Prc16KRotated = 93,
    /**
     * 97mm x 151mm
     */
    Prc32KRotated = 94,
    /**
     * 97mm x 151mm
     */
    Prc32KBigRotated = 95,
    /**
     * 165mm x 102mm
     */
    PrcEnvelopeNumber1Rotated = 96,
    /**
     * 176mm x 102mm
     */
    PrcEnvelopeNumber2Rotated = 97,
    /**
     * 176mm x 125mm
     */
    PrcEnvelopeNumber3Rotated = 98,
    /**
     * 208mm x 110mm
     */
    PrcEnvelopeNumber4Rotated = 99,
    /**
     * 220mm x 110mm
     */
    PrcEnvelopeNumber5Rotated = 100,
    /**
     * 230mm x 120mm
     */
    PrcEnvelopeNumber6Rotated = 101,
    /**
     * 230mm x 160mm
     */
    PrcEnvelopeNumber7Rotated = 102,
    /**
     * 309mm x 120mm
     */
    PrcEnvelopeNumber8Rotated = 103,
    /**
     * 324mm x 229mm
     */
    PrcEnvelopeNumber9Rotated = 104,
    /**
     * 458mm x 324mm
     */
    PrcEnvelopeNumber10Rotated = 105
}
/**
 * Paper size for PDF pages
 */
export interface CustomPaperSize {
    /**
     * Width custom paper width in mm
     */
    width: number;
    /**
     * Height custom paper height in mm
     */
    height: number;
    /**
     * Dimensions or unit of mature
     */
    unit: PaperSizeUnit;
}
/**
 * Paper Orientation
 */
export declare enum PdfPaperOrientation {
    /**
     * Paper is oriented vertically
     */
    Portrait = 0,
    /**
     * Paper is oriented horizontally
     */
    Landscape = 1
}
/**
 * Dimensions or unit of mature
 */
export declare enum PaperSizeUnit {
    Millimeter = 0,
    Inch = 1,
    Centimeter = 2,
    Points = 3
}
//# sourceMappingURL=paper.d.ts.map